@@ -3,7 +3,7 @@
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
 # Author: "Chris Ward" <cward@redhat.com>
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-version_info = ('0', '1', '0', '4a')
+version_info = ('0', '1', '1', '1')
 __version__ = '.'.join(version_info[0:3]) + '-' + version_info[3]
